# vi: ts=4 expandtab
#
#    Copyright (C) 2012 Canonical Ltd.
#    Copyright (C) 2012 Hewlett-Packard Development Company, L.P.
#    Copyright (C) 2012 Yahoo! Inc.
#
#    Author: Scott Moser <scott.moser@canonical.com>
#    Author: Juerg Haefliger <juerg.haefliger@hp.com>
#    Author: Joshua Harlow <harlowja@yahoo-inc.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License version 3, as
#    published by the Free Software Foundation.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from cloudinit.distros import rhel

from cloudinit import log as logging
from cloudinit import util

LOG = logging.getLogger(__name__)


class Distro(rhel.Distro):
    default_user = 'ec2-user'

    def set_hostname(self, hostname):
        # sysconfig-based (inherited from rhel.Distro)
        sysconfig_fname = self._paths.join(False, '/etc/sysconfig/network')
        self._write_hostname(hostname, '/etc/sysconfig/network')
        # systemd-based
        etc_fname = self._paths.join(False, '/etc/hostname')
        util.write_file(etc_fname, str(hostname) + '\n', 0644)

        if sysconfig_fname == '/etc/sysconfig/network':
            # Only do this if we are running in non-adjusted root mode
            LOG.debug('Setting hostname to %s', hostname)
            util.subp(['hostname', hostname])
